@@ -10,9 +10,11 @@ from naveen.data.pipe_cleaner import PipeCleaner
 from naveen.data.scrapers.html_extractor import HTMLExtractor
 from naveen.data.scrapers.html_tag_stripper import HTMLTagStripper
 from bs4 import BeautifulSoup
-from naveen.experiment.config.dynamic_config_maker import DynamicConfigMaker
+from naveen.experiment.config.dynamic_experiment_config_maker import DynamicExperimentConfigMaker  # noqa: E501
+from naveen.experiment.experiment_group_runner import ExperimentGroupRunner  # type: ignore # noqa: E501
 from naveen.experiment.experiment_runner import ExperimentRunner  # type: ignore # noqa: E501
 
+
 from naveen.utils.ngram_maker import NgramMaker
 
 
@@ -184,7 +186,13 @@ def pluck() -> None:
 
 
 def clean() -> None:
-    # 'Simple utility that returns a file name if the extension is added
+    '''
+    # expected use
+    # echo "test/fixtures/config/voss" | clean -e ".gz" =>
+    # test/fixtures/config/voss.gz does not exist so print filename
+    # echo "test/fixtures/config/voss" | clean -e ".json", prints "already exists"  # noqa: E501
+    '''
+    # returns a file name if the future file name does not yet exist
     parser = argparse.ArgumentParser(description="skip steps in pipe")
 
     parser.add_argument('-e', '--e', '--extension',
@@ -212,14 +220,6 @@ def clean() -> None:
         args.output_dir,
         args.verbose)
 
-    '''
-    # expected use
-    # alias pipecleaner="python src/data/pipe_cleaner.py"
-    # echo "test/fixtures/config/voss" | clean -e ".gz" =>
-    # test/fixtures/config/voss.gz does not exist so print filename
-    # echo "test/fixtures/config/voss" | clean -e ".json", prints "already exists"  # noqa: E501
-    '''
-
     if sys.stdin.isatty():  # no pipe
         print("- You must pipe input to this program")
     else:
@@ -258,6 +258,32 @@ def ngrams() -> None:
             print(n)
 
 
+def group() -> None:
+    parser = argparse.ArgumentParser()
+    help = "Run an experiment group from a config file"
+    parser.add_argument("-c", "--config",
+                        help=help,
+                        type=str,
+                        dest="config",
+                        required=True)
+    parser.add_argument("-p", "--package_name",
+                        help=help,
+                        type=str,
+                        dest="package_name",
+                        required=True)
+    parser.add_argument("-o", "--outputdir",
+                        type=str,
+                        dest="outputdir",
+                        default="results")
+    args = parser.parse_args()
+
+    sys.path.append(args.package_name)
+    assert args.config.endswith("yaml"), "The group config must be YAML"
+    runner = ExperimentGroupRunner(config_path=args.config)
+    runner.run(outputdir=args.outputdir,
+               package_name=args.package_name)
+
+
 def experiment() -> None:
     parser = argparse.ArgumentParser()
     help = "Run an experiment from a config file"
@@ -281,12 +307,15 @@ def experiment() -> None:
 
     sys.path.append(os.getcwd())
 
-    maker = DynamicConfigMaker()
-    msg = "Your config is {}. ".format(args.config)
-    msg += "For now we assume config is json"
-    assert args.config[-5:] == ".json", msg
-    config = maker.from_json(args.config)
+    maker = DynamicExperimentConfigMaker()
+    msg = "Your config {} must be json or yaml".format(args.config)
+    assert args.config[-4] in ['yaml', 'json', '.yml'], msg
+    if args.config[-4:] == "json":
+        config = maker.from_json(args.config)
+    else:
+        config = maker.from_yaml(args.config)
     name = args.outputdir + "/" + config.name + str(int(time.time()))
+
     runner = ExperimentRunner(config,
                               package_name=args.package_name,
                               output_directory=name)
